.. Sample from https://docutils.sourceforge.io/docs/ref/rst/directives.html#math

A ``math`` directive:

.. math::

  α_t(i) = P(O_1, O_2, … O_t, q_t = S_i λ)


.. Sample from https://docutils.sourceforge.io/docs/ref/rst/roles.html#math

A ``:math:`` role:

The area of a circle is :math:`A_\text{c} = (\pi/4) d^2`.
